document.addEventListener('DOMContentLoaded', () => {
  const calculateBtn = document.getElementById('calculate');
  const totalPriceElement = document.getElementById('total-price');
  const breakdownList = document.getElementById('breakdown-list');

  const basePrices = {
    eggs: {
      small: 0.15,
      medium: 0.20,
      large: 0.25,
      xlarge: 0.30
    },
    chicken: {
      small: 8.00,
      medium: 10.00,
      large: 12.00,
      xlarge: 15.00
    }
  };

  const qualityMultipliers = {
    B: 0.9,
    A: 1.0,
    AA: 1.2
  };

  function calculatePrice() {
    const quantity = parseInt(document.getElementById('quantity').value);
    const size = document.getElementById('size').value;
    const quality = document.getElementById('quality').value;
    const type = document.getElementById('type').value;

    const basePrice = basePrices[type][size];
    const qualityMultiplier = qualityMultipliers[quality];
    const subtotal = basePrice * quantity;
    const qualityAdjustment = subtotal * (qualityMultiplier - 1);
    const total = subtotal + qualityAdjustment;

    // Update total price display
    totalPriceElement.textContent = `$${total.toFixed(2)}`;

    // Update breakdown
    breakdownList.innerHTML = `
      <li>
        <span>Base Price (${quantity} × $${basePrice.toFixed(2)})</span>
        <span>$${subtotal.toFixed(2)}</span>
      </li>
      <li>
        <span>Quality Adjustment (Grade ${quality})</span>
        <span>$${qualityAdjustment.toFixed(2)}</span>
      </li>
    `;

    // Add animation
    totalPriceElement.classList.add('price-updated');
    setTimeout(() => {
      totalPriceElement.classList.remove('price-updated');
    }, 300);
  }

  calculateBtn.addEventListener('click', calculatePrice);

  // Calculate initial price
  calculatePrice();
});